# Copyright 2024-present Coinbase Global, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from .service import WalletsService
from .create_wallet import (
    CreateWalletRequest,
    CreateWalletResponse
)
from .create_wallet_address import (
    CreateWalletAddressRequest,
    CreateWalletAddressResponse
)
from .get_wallet import (
    GetWalletRequest,
    GetWalletResponse
)
from .get_wallet_deposit_instructions import (
    GetWalletDepositInstructionsRequest,
    GetWalletDepositInstructionsResponse
)
from .list_wallet_addresses import (
    ListWalletAddressesRequest,
    ListWalletAddressesResponse
)
from .list_wallets import (
    ListWalletsRequest,
    ListWalletsResponse
)

__all__ = [
    "WalletsService",
    "CreateWalletRequest",
    "CreateWalletResponse",
    "CreateWalletAddressRequest",
    "CreateWalletAddressResponse",
    "GetWalletRequest",
    "GetWalletResponse",
    "GetWalletDepositInstructionsRequest",
    "GetWalletDepositInstructionsResponse",
    "ListWalletAddressesRequest",
    "ListWalletAddressesResponse",
    "ListWalletsRequest",
    "ListWalletsResponse"
]