# Copyright 2025-present Coinbase Global, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from dataclasses import dataclass
from typing import Optional, List
from ...model import Candle
from ...base_response import BaseResponse
from ...utils import PaginationParams, Pagination


@dataclass
class GetProductCandlesRequest:
    portfolio_id: str
    product_id: str
    granularity: str
    start_time: int
    end_time: int
    pagination: Optional[PaginationParams] = None
    allowed_status_codes: Optional[List[int]] = None


@dataclass
class GetProductCandlesResponse(BaseResponse):
    candles: List[Candle] = None
    pagination: Pagination = None